@@ -7,7 +7,7 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2014 Magic3 Project.
+ * @copyright  Copyright 2006-2017 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
  * @version    1.0
  * @link       http://www.magic3.org
@@ -42,5 +42,6 @@ CKEDITOR.plugins.setLang( 'googlemaps', 'en', {
 	mapType: 'Map Type',
 	msgDefaultMarkerText:	'Input text.',
 	msgInputStyleJsonData: 'Input style data by JSON format.',
-	msgInvalidStyle: 'Invalid JSON data.'
+	msgInvalidStyle: 'Invalid JSON data.',
+	msgApiKeyNotConfigured: 'Google Maps API key not configured.'
 });
