@@ -21,11 +21,12 @@ class elFinderConnector {
 	protected $options = array();
 	
 	/**
-	 * undocumented class variable
+	 * Must be use output($data) $data['header']
 	 *
 	 * @var string
+	 * @deprecated
 	 **/
-	protected $header = 'Content-Type: application/json';
+	protected $header = '';
 
 	/**
 	 * HTTP request method
@@ -34,6 +35,13 @@ class elFinderConnector {
 	 */
 	protected $reqMethod = '';
 	
+	/**
+	 * Content type of output JSON
+	 * 
+	 * @var string
+	 */
+	protected static $contentType = 'Content-Type: application/json';
+	
 	/**
 	 * Constructor
 	 *
@@ -46,7 +54,7 @@ class elFinderConnector {
 		$this->elFinder = $elFinder;
 		$this->reqMethod = strtoupper($_SERVER["REQUEST_METHOD"]);
 		if ($debug) {
-			$this->header = 'Content-Type: text/html; charset=utf-8';
+			self::$contentType = 'Content-Type: text/plain; charset=utf-8';
 		}
 	}
 	
@@ -58,26 +66,41 @@ class elFinderConnector {
 	 **/
 	public function run() {
 		$isPost = $this->reqMethod === 'POST';
-		$src    = $isPost ? $_POST : $_GET;
-		if ($isPost && !$src && $rawPostData = @file_get_contents('php://input')) {
-			// for support IE XDomainRequest()
+		$src    = $isPost ? array_merge($_GET, $_POST) : $_GET;
+		$maxInputVars = (! $src || isset($src['targets']))? ini_get('max_input_vars') : null;
+		if ((! $src || $maxInputVars) && $rawPostData = file_get_contents('php://input')) {
+			// for max_input_vars and supports IE XDomainRequest()
 			$parts = explode('&', $rawPostData);
-			foreach($parts as $part) {
-				list($key, $value) = array_pad(explode('=', $part), 2, '');
-				$key = rawurldecode($key);
-				if (substr($key, -2) === '[]') {
-					$key = substr($key, 0, strlen($key) - 2);
-					if (!isset($src[$key])) {
-						$src[$key] = array();
+			if (! $src || $maxInputVars < count($parts)) {
+				$src = array();
+				foreach($parts as $part) {
+					list($key, $value) = array_pad(explode('=', $part), 2, '');
+					$key = rawurldecode($key);
+					if (preg_match('/^(.+?)\[([^\[\]]*)\]$/', $key, $m)) {
+						$key = $m[1];
+						$idx = $m[2];
+						if (!isset($src[$key])) {
+							$src[$key] = array();
+						}
+						if ($idx) {
+							$src[$key][$idx] = rawurldecode($value);
+						} else {
+							$src[$key][] = rawurldecode($value);
+						}
+					} else {
+						$src[$key] = rawurldecode($value);
 					}
-					$src[$key][] = rawurldecode($value);
-				} else {
-					$src[$key] = rawurldecode($value);
 				}
+				$_POST = $this->input_filter($src);
+				$_REQUEST = $this->input_filter(array_merge_recursive($src, $_REQUEST));
 			}
-			$_POST = $this->input_filter($src);
-			$_REQUEST = $this->input_filter(array_merge_recursive($src, $_REQUEST));
 		}
+		
+		if (isset($src['targets']) && $this->elFinder->maxTargets && count($src['targets']) > $this->elFinder->maxTargets) {
+			$error = $this->elFinder->error(elFinder::ERROR_MAX_TARGTES);
+			$this->output(array('error' => $this->elFinder->error(elFinder::ERROR_MAX_TARGTES)));
+		}
+		
 		$cmd    = isset($src['cmd']) ? $src['cmd'] : '';
 		$args   = array();
 		
@@ -129,7 +152,14 @@ class elFinderConnector {
 			$args['FILES'] = $_FILES;
 		}
 		
-		$this->output($this->elFinder->exec($cmd, $args));
+		try {
+			$this->output($this->elFinder->exec($cmd, $args));
+		} catch (elFinderAbortException $e) {
+			// connection aborted
+			// unlock session data for multiple access
+			$this->elFinder->getSession()->close();
+			exit();
+		}
 	}
 	
 	/**
@@ -140,25 +170,31 @@ class elFinderConnector {
 	 * @author Dmitry (dio) Levashov
 	 **/
 	protected function output(array $data) {
-		// clear output buffer
-		while(ob_get_level() && ob_end_clean()){}
+		// unlock session data for multiple access
+		$this->elFinder->getSession()->close();
+		// client disconnect should abort
+		ignore_user_abort(false);
 		
-		$header = isset($data['header']) ? $data['header'] : $this->header;
-		unset($data['header']);
-		if ($header) {
-			if (is_array($header)) {
-				foreach ($header as $h) {
-					header($h);
-				}
-			} else {
-				header($header);
-			}
+		if ($this->header) {
+			self::sendHeader($this->header);
 		}
 		
 		if (isset($data['pointer'])) {
+			// set time limit to 0
+			elFinder::extendTimeLimit(0);
+			
+			// send optional header
+			if (!empty($data['header'])) {
+				self::sendHeader($data['header']);
+			}
+			
+			// clear output buffer
+			while(ob_get_level() && ob_end_clean()){}
+			
 			$toEnd = true;
 			$fp = $data['pointer'];
-			if (($this->reqMethod === 'GET' || $this->reqMethod === 'HEAD')
+			$sendData = !($this->reqMethod === 'HEAD' || !empty($data['info']['xsendfile']));
+			if (($this->reqMethod === 'GET' || !$sendData)
 					&& elFinder::isSeekableStream($fp)
 					&& (array_search('Accept-Ranges: none', headers_list()) === false)) {
 				header('Accept-Ranges: bytes');
@@ -187,11 +223,24 @@ class elFinderConnector {
 							header('Content-Length: ' . $psize);
 							header('Content-Range: bytes ' . $start . '-' . $end . '/' . $size);
 							
-							fseek($fp, $start);
+							// Apache mod_xsendfile dose not support range request
+							if (isset($data['info']['xsendfile']) && strtolower($data['info']['xsendfile']) === 'x-sendfile') {
+								if (function_exists('header_remove')) {
+									header_remove($data['info']['xsendfile']);
+								} else {
+									header($data['info']['xsendfile'] . ':');
+								}
+								unset($data['info']['xsendfile']);
+								if ($this->reqMethod !== 'HEAD') {
+									$sendData = true;
+								}
+							}
+							
+							$sendData && fseek($fp, $start);
 						}
 					}
 				}
-				if (is_null($psize)){
+				if ($sendData && is_null($psize)){
 					elFinder::rewind($fp);
 				}
 			} else {
@@ -205,12 +254,7 @@ class elFinderConnector {
 				}
 			}
 
-			// unlock session data for multiple access
-			$this->elFinder->getSession()->close();
-			// client disconnect should abort
-			ignore_user_abort(false);
-
-			if ($reqMethod !== 'HEAD') {
+			if ($sendData) {
 				if ($toEnd) {
 					fpassthru($fp);
 				} else {
@@ -225,18 +269,9 @@ class elFinderConnector {
 			}
 			exit();
 		} else {
-			if (!empty($data['raw']) && !empty($data['error'])) {
-				echo $data['error'];
-			} else {
-				if (isset($data['debug']) && isset($data['debug']['phpErrors'])) {
-					$data['debug']['phpErrors'] = array_merge($data['debug']['phpErrors'], elFinder::$phpErrors);
-				}
-				echo json_encode($data);
-			}
-			flush();
+			self::outputJson($data);
 			exit(0);
 		}
-		
 	}
 	
 	/**
@@ -259,4 +294,52 @@ class elFinderConnector {
 		$magic_quotes_gpc && ($res = stripslashes($res));
 		return $res;
 	}
+	
+	/**
+	 * Send HTTP header
+	 * 
+	 * @param string|array $header optional header
+	 */
+	protected static function sendHeader($header = null) {
+		if ($header) {
+			if (is_array($header)) {
+				foreach ($header as $h) {
+					header($h);
+				}
+			} else {
+				header($header);
+			}
+		}
+	}
+	
+	/**
+	 * Output JSON
+	 * 
+	 * @param array $data
+	 */
+	public static function outputJson($data) {
+		// send header
+		$header = isset($data['header']) ? $data['header'] : self::$contentType;
+		self::sendHeader($header);
+		
+		unset($data['header']);
+		
+		if (!empty($data['raw']) && isset($data['error'])) {
+			$out = $data['error'];
+		} else {
+			if (isset($data['debug']) && isset($data['debug']['phpErrors'])) {
+				$data['debug']['phpErrors'] = array_merge($data['debug']['phpErrors'], elFinder::$phpErrors);
+			}
+			$out = json_encode($data);
+		}
+		
+		// clear output buffer
+		while(ob_get_level() && ob_end_clean()){}
+		
+		header('Content-Length: ' . strlen($out));
+		
+		echo $out;
+		
+		flush();
+	}
 }// END class 
