@@ -8,7 +8,7 @@
  *
  * @package    パンくずリスト
  * @author     株式会社 毎日メディアサービス
- * @copyright  Copyright 2010 株式会社 毎日メディアサービス.
+ * @copyright  Copyright 2010-2018 株式会社 毎日メディアサービス.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
  * @version    SVN: $Id: breadcrumbDb.php 3521 2010-08-23 04:08:41Z fishbone $
  * @link       http://www.m-media.co.jp
@@ -29,7 +29,7 @@ class breadcrumbDb extends BaseDb
 	 */
 	function getMenuId($useHiddenMenu, $pageId, $pageSubId, &$rows, $setId = 0)
 	{	
-		$queryStr  = 'SELECT DISTINCT pd_menu_id, pd_sub_id, ';
+		$queryStr  = 'SELECT DISTINCT pd_menu_id, pd_sub_id, mn_sort_order, ';
 		$queryStr .=   'CASE pd_sub_id ';
 		$queryStr .=     'WHEN \'\' THEN -1 ';
 		$queryStr .=     'ELSE pg_priority ';
@@ -40,11 +40,11 @@ class breadcrumbDb extends BaseDb
 		$queryStr .= 'WHERE pd_id = ? ';
 		$queryStr .=   'AND (pd_sub_id = ? or pd_sub_id = \'\') ';	// 空の場合は共通項目
 		$queryStr .=   'AND pd_set_id = ? ';
-		$queryStr .=   'AND pd_menu_id != ? ';				// メニューIDが設定されている
+		$queryStr .=   'AND pd_menu_id != \'\' ';				// メニューIDが設定されている
 		if (empty($useHiddenMenu)) $queryStr .=   'AND pd_visible = true ';			// ウィジェットは表示中
 		$queryStr .=   'AND wd_deleted = false ';			// ウィジェットは削除されていない
 		$queryStr .= 'ORDER BY idx, mn_sort_order';
-		$retValue = $this->selectRecords($queryStr, array($pageId, $pageSubId, $setId, ''), $rows);
+		$retValue = $this->selectRecords($queryStr, array($pageId, $pageSubId, $setId), $rows);
 		return $retValue;
 	}
 	/**
