@@ -8,7 +8,7 @@
  *
  * @package    フリーレイアウトお問い合わせ
  * @author     株式会社 毎日メディアサービス
- * @copyright  Copyright 2009-2016 株式会社 毎日メディアサービス.
+ * @copyright  Copyright 2009-2018 株式会社 毎日メディアサービス.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
  * @version    SVN: $Id$
  * @link       http://www.m-media.co.jp
@@ -35,6 +35,8 @@ class admin_contactus_freelayout3WidgetContainer extends BaseAdminWidgetContaine
 	const UPLOAD_MAX_SIZE = '2M';		// アップロード最大ファイルサイズ(バイト)
 	const UPLOAD_MAX_COUNT = 5;			// アップロードファイル最大数
 	const UPLOAD_FILE_EXTENSION = 'png,gif,jpg,jpeg';		// アップロード可能なファイルの拡張子
+	const OPEN_PANEL_ICON_FILE = '/images/system/plus32.png';		// 拡張エリア表示用アイコン
+	const CLOSE_PANEL_ICON_FILE = '/images/system/minus32.png';		// 拡張エリア非表示用アイコン
 	
 	/**
 	 * コンストラクタ
@@ -177,6 +179,11 @@ class admin_contactus_freelayout3WidgetContainer extends BaseAdminWidgetContaine
 		$uploadMaxCount = $request->trimValueOf('item_upload_max_count');		// アップロードファイル最大数
 		$uploadFileExtension = $request->trimValueOf('item_upload_file_extension');		// アップロード可能なファイルの拡張子
 		$uploadArea = $request->valueOf('item_upload_area');		// ファイルアップロードエリア
+		$msgConfirm = $request->trimValueOf('item_msg_confirm');		// 確認画面メッセージ
+		$msgComplete = $request->trimValueOf('item_msg_complete');		// 完了画面メッセージ
+		$contentComplete = $request->valueOf('item_content_complete');		// 完了画面コンテンツ
+		$accessKey = $request->trimValueOf('item_access_key');		// 発行アクセスキー
+		$hideInComplete	= $request->trimCheckedValueOf('item_hide_in_complete');			// お問い合わせ項目を送信完了画面で隠すかどうか
 		
 		// 入力データを取得
 		$this->fieldInfoArray = array();
@@ -247,6 +254,9 @@ class admin_contactus_freelayout3WidgetContainer extends BaseAdminWidgetContaine
 			$this->checkSingleByte($uploadMaxSize, 'アップロード最大ファイルサイズ');
 			$this->checkInput($uploadFileExtension, 'アップロード可能なファイルの拡張子');
 		
+			// 発行アクセスキー
+			$this->checkSingleByte($accessKey, '発行アクセスキー', true);
+		
 			// エラーなしの場合は、データを登録
 			if ($this->getMsgCount() == 0){
 				// ファイルアップロードエリアが空のときはデフォルトを取得
@@ -255,6 +265,9 @@ class admin_contactus_freelayout3WidgetContainer extends BaseAdminWidgetContaine
 				// ファイルアップロードエリアをマクロ表現に変換
 				$uploadArea = $this->gInstance->getTextConvManager()->convToContentMacro($uploadArea);
 				
+				// データ修正
+				$uploadFileExtension = implode(',', array_map('trim', explode(',', $uploadFileExtension)));
+				
 				// 追加オブジェクト作成
 				$newObj = new stdClass;
 				$newObj->name		= $name;// 表示名
@@ -277,9 +290,18 @@ class admin_contactus_freelayout3WidgetContainer extends BaseAdminWidgetContaine
 				$newObj->uploadFileExtension = $uploadFileExtension;	// アップロード可能なファイルの拡張子
 				$newObj->uploadArea = $uploadArea;		// ファイルアップロードエリア
 				$newObj->fieldInfo	= $this->fieldInfoArray;		// フィールド定義
+				$newObj->msgConfirm = $msgConfirm;		// 確認画面メッセージ
+				$newObj->msgComplete = $msgComplete;		// 完了画面メッセージ
+				$newObj->contentComplete = $contentComplete;		// 完了画面コンテンツ
+				$newObj->accessKey = $accessKey;		// 発行アクセスキー
+				$newObj->hideInComplete	= $hideInComplete;			// お問い合わせ項目を送信完了画面で隠すかどうか
 				
 				$ret = $this->addPageDefParam($defSerial, $defConfigId, $this->paramObj, $newObj);
 				if ($ret){
+					// ##### アクセスキー情報を登録 #####
+					$this->gAccess->unegistAllSessionAccessKey($defConfigId);		// 一旦すべて削除
+					if (!empty($accessKey)) $this->gAccess->registSessionAccessKey($accessKey, $defConfigId, 1/*発行*/);
+					
 					$this->setGuidanceMsg('データを追加しました');
 					
 					$this->configId = $defConfigId;		// 定義定義IDを更新
@@ -325,6 +347,9 @@ class admin_contactus_freelayout3WidgetContainer extends BaseAdminWidgetContaine
 			$this->checkSingleByte($uploadMaxSize, 'アップロード最大ファイルサイズ');
 			$this->checkInput($uploadFileExtension, 'アップロード可能なファイルの拡張子');
 			
+			// 発行アクセスキー
+			$this->checkSingleByte($accessKey, '発行アクセスキー', true);
+			
 			if ($this->getMsgCount() == 0){			// エラーのないとき
 				// ファイルアップロードエリアが空のときはデフォルトを取得
 				if (empty($uploadArea)) $uploadArea = $this->gDesign->createDragDropFileUploadHtml();
@@ -332,6 +357,9 @@ class admin_contactus_freelayout3WidgetContainer extends BaseAdminWidgetContaine
 				// ファイルアップロードエリアをマクロ表現に変換
 				$uploadArea = $this->gInstance->getTextConvManager()->convToContentMacro($uploadArea);
 				
+				// データ修正
+				$uploadFileExtension = implode(',', array_map('trim', explode(',', $uploadFileExtension)));
+				
 				// 現在の設定値を取得
 				$ret = $this->getPageDefParam($defSerial, $defConfigId, $this->paramObj, $this->configId, $targetObj);
 				if ($ret){
@@ -355,11 +383,20 @@ class admin_contactus_freelayout3WidgetContainer extends BaseAdminWidgetContaine
 					$targetObj->uploadFileExtension = $uploadFileExtension;	// アップロード可能なファイルの拡張子
 					$targetObj->uploadArea = $uploadArea;		// ファイルアップロードエリア
 					$targetObj->fieldInfo	= $this->fieldInfoArray;		// フィールド定義
+					$targetObj->msgConfirm = $msgConfirm;		// 確認画面メッセージ
+					$targetObj->msgComplete = $msgComplete;		// 完了画面メッセージ
+					$targetObj->contentComplete = $contentComplete;		// 完了画面コンテンツ
+					$targetObj->accessKey = $accessKey;		// 発行アクセスキー
+					$targetObj->hideInComplete	= $hideInComplete;			// お問い合わせ項目を送信完了画面で隠すかどうか
 				}
 				
 				// 設定値を更新
 				if ($ret) $ret = $this->updatePageDefParam($defSerial, $defConfigId, $this->paramObj, $this->configId, $targetObj);
 				if ($ret){
+					// ##### アクセスキー情報を登録 #####
+					$this->gAccess->unegistAllSessionAccessKey($defConfigId);		// 一旦すべて削除
+					if (!empty($accessKey)) $this->gAccess->registSessionAccessKey($accessKey, $defConfigId, 1/*発行*/);
+					
 					$this->setMsg(self::MSG_GUIDANCE, 'データを更新しました');
 					$replaceNew = true;			// データ再取得
 				} else {
@@ -396,6 +433,11 @@ class admin_contactus_freelayout3WidgetContainer extends BaseAdminWidgetContaine
 				$uploadFileExtension = self::UPLOAD_FILE_EXTENSION;		// アップロード可能なファイルの拡張子
 				$uploadArea = $this->gDesign->createDragDropFileUploadHtml();		// ファイルアップロードエリア
 				$this->fieldInfoArray = array();			// お問い合わせ項目情報
+				$msgConfirm = '';		// 確認画面メッセージ
+				$msgComplete = '';		// 完了画面メッセージ
+				$contentComplete = '';		// 完了画面コンテンツ
+				$accessKey = '';		// 発行アクセスキー
+				$hideInComplete	= 0;			// お問い合わせ項目を送信完了画面で隠すかどうか
 				
 				// デフォルトのテンプレート作成
 				$tagHead = $this->createTagIdHead();
@@ -435,6 +477,11 @@ class admin_contactus_freelayout3WidgetContainer extends BaseAdminWidgetContaine
 					if (empty($uploadArea)) $uploadArea = $this->gDesign->createDragDropFileUploadHtml();		// ファイルアップロードエリア
 					$uploadArea = str_replace(M3_TAG_START . M3_TAG_MACRO_ROOT_URL . M3_TAG_END, $this->getUrl($this->gEnv->getRootUrl()), $uploadArea);				// アプリケーションルートを変換
 					if (!empty($targetObj->fieldInfo)) $this->fieldInfoArray = $targetObj->fieldInfo;			// お問い合わせ項目情報
+					$msgConfirm = $targetObj->msgConfirm;		// 確認画面メッセージ
+					$msgComplete = $targetObj->msgComplete;		// 完了画面メッセージ
+					$contentComplete = $targetObj->contentComplete;		// 完了画面コンテンツ
+					$accessKey = $targetObj->accessKey;		// 発行アクセスキー
+					$hideInComplete	= $targetObj->hideInComplete;			// お問い合わせ項目を送信完了画面で隠すかどうか
 				}
 			}
 			$this->serialNo = $this->configId;
@@ -481,6 +528,21 @@ class admin_contactus_freelayout3WidgetContainer extends BaseAdminWidgetContaine
 		$this->tmpl->addVar("_widget", "serial", $this->serialNo);// 選択中のシリアル番号、IDを設定
 		$this->tmpl->addVar('_widget', 'tag_start', M3_TAG_START . M3_TAG_MACRO_ITEM_KEY);		// 置換タグ(前)
 		$this->tmpl->addVar('_widget', 'tag_end', M3_TAG_END);		// 置換タグ(後)
+		$this->tmpl->addVar('_widget', 'msg_confirm', $this->convertToDispString($msgConfirm));		// 確認画面メッセージ
+		$this->tmpl->addVar('_widget', 'msg_complete', $this->convertToDispString($msgComplete));		// 完了画面メッセージ
+		$this->tmpl->addVar('_widget', 'content_complete', $contentComplete);		// 完了画面メッセージ
+		$this->tmpl->addVar('_widget', 'access_key', $this->convertToDispString($accessKey));		// 発行アクセスキー
+		$this->tmpl->addVar("_widget", "hide_in_complete_checked", $this->convertToCheckedString($hideInComplete));			// お問い合わせ項目を送信完了画面で隠すかどうか
+		
+		// 項目追加処理内のオプション領域制御
+		$iconUrl = $this->gEnv->getRootUrl() . self::OPEN_PANEL_ICON_FILE;		// 拡張エリア表示用アイコン
+		$iconTitle = 'オプションを表示';
+		$openButton = '<a href="javascript:void(0);" class="button_open btn btn-sm btn-warning" role="button" rel="m3help" data-container="body" title="' . $iconTitle . '"><i class="glyphicon glyphicon-plus"></i></a>';
+		$this->tmpl->addVar('_widget', 'open_button', $openButton);
+		$iconUrl = $this->gEnv->getRootUrl() . self::CLOSE_PANEL_ICON_FILE;		// 拡張エリア非表示用アイコン
+		$iconTitle = 'オプションを非表示';
+		$closeButton = '<a href="javascript:void(0);" class="button_close btn btn-sm btn-warning" role="button" rel="m3help" data-container="body" title="' . $iconTitle . '" style="display:none;"><i class="glyphicon glyphicon-minus"></i></a>';
+		$this->tmpl->addVar('_widget', 'close_button', $closeButton);
 		
 		// ボタンの表示制御
 		if (empty($this->serialNo)){		// 新規追加項目を選択しているとき
@@ -571,6 +633,14 @@ class admin_contactus_freelayout3WidgetContainer extends BaseAdminWidgetContaine
 				$this->tmpl->parseTemplate('type_list2', 'a');
 			}
 			
+			// オプション領域
+			$iconUrl = $this->gEnv->getRootUrl() . self::OPEN_PANEL_ICON_FILE;		// 拡張エリア表示用アイコン
+			$iconTitle = 'オプションを表示';
+			$openButton = '<a href="javascript:void(0);" class="button_open btn btn-sm btn-warning" role="button" rel="m3help" data-container="body" title="' . $iconTitle . '"><i class="glyphicon glyphicon-plus"></i></a>';
+			$iconUrl = $this->gEnv->getRootUrl() . self::CLOSE_PANEL_ICON_FILE;		// 拡張エリア非表示用アイコン
+			$iconTitle = 'オプションを非表示';
+			$closeButton = '<a href="javascript:void(0);" class="button_close btn btn-sm btn-warning" role="button" rel="m3help" data-container="body" title="' . $iconTitle . '" style="display:none;"><i class="glyphicon glyphicon-minus"></i></a>';
+		
 			$row = array(
 				'title' => $this->convertToDispString($title),	// タイトル名
 				'desc' => $this->convertToDispString($desc),	// 説明
@@ -583,7 +653,9 @@ class admin_contactus_freelayout3WidgetContainer extends BaseAdminWidgetContaine
 				'default' => $this->convertToDispString($default),	// デフォルト値
 				'field_id' => $this->convertToDispString($fieldId),		// フィールドID
 				'calc' => $this->convertToDispString($calc),			// 計算式
-				'root_url' => $this->convertToDispString($this->getUrl($this->gEnv->getRootUrl()))
+				'root_url' => $this->convertToDispString($this->getUrl($this->gEnv->getRootUrl())),
+				'open_button' => $openButton,
+				'close_button' => $closeButton
 			);
 			$this->tmpl->addVars('field_list', $row);
 			$this->tmpl->parseTemplate('field_list', 'a');
