@@ -8,7 +8,7 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2017 Magic3 Project.
+ * @copyright  Copyright 2006-2018 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
  * @version    SVN: $Id$
  * @link       http://www.magic3.org
@@ -40,6 +40,9 @@ class default_contentWidgetContainer extends default_contentBaseWidgetContainer
 	private $useJQuery;						// jQueryスクリプト作成を行うかどうか
 	private $headScript;	// HTMLヘッダに埋め込むJavascript
 	private $addLib = array();		// 追加スクリプトライブラリ
+	private $autoGenerateAttachFileList;		// 添付ファイルリストを自動作成するかどうか
+	private $attachFileRows;		// 添付ファイル情報(コンテンツ本文作成用)
+	private $attachFileDownloadUrl;			// 添付ファイルのリンク先URL
 	const DEFAULT_LIST_COUNT = 10;			// 最大リスト表示数
 	const DEFAULT_SEARCH_LIST_COUNT = 20;			// 最大リスト表示数(検索用)
 	const MESSAGE_NO_CONTENT		= 'コンテンツが見つかりません';
@@ -77,6 +80,7 @@ class default_contentWidgetContainer extends default_contentBaseWidgetContainer
 		$this->outputHead = self::$_configArray[default_contentCommonDef::$CF_OUTPUT_HEAD];			// ヘッダ出力するかどうか
 		$this->passwordFormCount = 0;		// パスワード入力フォーム数
 		$this->useJQuery = self::$_configArray[default_contentCommonDef::$CF_USE_JQUERY];			// jQueryスクリプトを作成するかどうか
+		$this->autoGenerateAttachFileList = self::$_configArray[default_contentCommonDef::CF_AUTO_GENERATE_ATTACH_FILE_LIST];		// 添付ファイルリストを自動作成するかどうか
 	}
 	/**
 	 * テンプレートファイルを設定
@@ -192,7 +196,6 @@ class default_contentWidgetContainer extends default_contentBaseWidgetContainer
 				$contentId = $attachFileRow[af_content_id];		// コンテンツID
 				
 				// コンテンツへのアクセス可能状況をチェック
-				//self::$_mainDb->getContentItems(default_contentCommonDef::$_contentType, array($this, 'checkItemsLoop'), array($contentId), $this->gEnv->getCurrentLanguage(), $all, $now, false);
 				self::$_mainDb->getContentItems(default_contentCommonDef::$_contentType, array($this, 'checkItemsLoop'), array($contentId), $this->gEnv->getDefaultLanguage(), $all, $now, false);
 				if ($this->_contentCreated){		// コンテンツにアクセスできるとき
 					// パスワード入力のアクセス権はデフォルト言語でチェック
@@ -205,6 +208,10 @@ class default_contentWidgetContainer extends default_contentBaseWidgetContainer
 							if (!is_array($this->sessionParamObj->authContentId) || !in_array($contentId, $this->sessionParamObj->authContentId)) $inputPassword = true;	// パスワード入力かどうか
 						}
 						if (!$inputPassword) $canDownload = true;		// ダウンロード可能
+						
+						// 添付ファイルへのアクセス情報を取得
+						$accessKey = $defaultContentRow['cn_attach_access_key'];		// アクセスキー
+						$accessUrl = $defaultContentRow['cn_attach_access_url'];		// アクセスキー取得用URL
 					}
 				}
 			}
@@ -212,32 +219,56 @@ class default_contentWidgetContainer extends default_contentBaseWidgetContainer
 			$this->gPage->abortPage();
 							
 			if ($canDownload){		// ダウンロード可能なとき
-				// 添付ファイル情報を取得
-				$downloadCompleted = false;				// ダウンロード処理完了かどうか
-				$contentSerial = $this->serialArray[0];		// アクセス可能なコンテンツのシリアル番号
-				$ret = $this->gInstance->getFileManager()->getAttachFileInfo(default_contentCommonDef::$_viewContentType, $contentSerial, $attachFileRows);
-				if ($ret){
-					for ($i = 0; $i < count($attachFileRows); $i++){
-						$fileRow = $attachFileRows[$i];
-						if ($fileId == $fileRow['af_file_id']){
-							$downloadFile = default_contentCommonDef::getAttachFileDir() . DIRECTORY_SEPARATOR . $fileId;
-							$downloadFilename = $fileRow['af_filename'];
-							if (empty($downloadFilename)) $downloadFilename = $fileRow['af_original_filename'];
+				// ##### 添付ファイルにアクセスキーが設定されている場合アクセス制御を行う #####
+				$canDownloadAttachFile = false;			// 添付ファイルダウンロード不可
+				$sessionAccessKey = '';
+				if (empty($accessKey)){
+					$canDownloadAttachFile = true;		// 添付ファイルダウンロード可
+				} else {
+					// セッションのアクセスキーを確認
+					$sessionAccessKey = $this->gAccess->getSessionAccessKey($accessKey);
+					if (!empty($sessionAccessKey)) $canDownloadAttachFile = true;		// 添付ファイルダウンロード可
+				}
+			
+				if ($canDownloadAttachFile){		// 添付ファイルダウンロード可能な場合
+					// 添付ファイル情報を取得
+					$downloadCompleted = false;				// ダウンロード処理完了かどうか
+					$contentSerial = $this->serialArray[0];		// アクセス可能なコンテンツのシリアル番号
+					$ret = $this->gInstance->getFileManager()->getAttachFileInfo(default_contentCommonDef::$_viewContentType, $contentSerial, $attachFileRows);
+					if ($ret){
+						for ($i = 0; $i < count($attachFileRows); $i++){
+							$fileRow = $attachFileRows[$i];
+							if ($fileId == $fileRow['af_file_id']){
+								$downloadFile = default_contentCommonDef::getAttachFileDir() . DIRECTORY_SEPARATOR . $fileId;
+								$downloadFilename = $fileRow['af_filename'];
+								if (empty($downloadFilename)) $downloadFilename = $fileRow['af_original_filename'];
 							
-							// ダウンロード処理
-							$ret = $this->gPage->downloadFile($downloadFile, $downloadFilename);
-							$downloadCompleted = true;				// ダウンロード処理完了かどうか
-							break;
+								// ダウンロード処理
+								$ret = $this->gPage->downloadFile($downloadFile, $downloadFilename);
+								$downloadCompleted = true;				// ダウンロード処理完了かどうか
+								break;
+							}
 						}
 					}
-				}
-				if ($downloadCompleted){		// ダウンロード処理完了のとき
-					// ダウンロードログを残す
-					$this->gInstance->getAnalyzeManager()->logContentDownload(default_contentCommonDef::$_viewContentType . default_contentCommonDef::DOWNLOAD_CONTENT_TYPE, $fileId);
-				} else {
-					$msgDetail = '';
-					if (!empty($contentId)) $msgDetail .= 'コンテンツID=' . $contentId;
-					$this->writeError(__METHOD__, '添付ファイルのダウンロードに失敗しました。添付ファイルが見つかりません。ファイルID=' . $fileId, 2200, $msgDetail);
+					if ($downloadCompleted){		// ダウンロード処理完了のとき
+						// ダウンロードログを残す
+						$this->gInstance->getAnalyzeManager()->logContentDownload(default_contentCommonDef::$_viewContentType . default_contentCommonDef::DOWNLOAD_CONTENT_TYPE, $fileId);
+					} else {
+						$msgDetail = '';
+						if (!empty($contentId)) $msgDetail .= 'コンテンツID=' . $contentId;
+						$this->writeError(__METHOD__, '添付ファイルのダウンロードに失敗しました。添付ファイルが見つかりません。ファイルID=' . $fileId, 2200, $msgDetail);
+					}
+				} else {		// 添付ファイルダウンロード不可の場合
+					// アクセスキー取得用のURLが設定されている場合はリダイレクト
+					if (empty($accessUrl)){		// アクセスキー取得用URLが設定されていない場合
+						$this->writeError(__METHOD__, '添付ファイルのアクセスキー取得用のURLが設定されていません。コンテンツID=' . $contentId, 2200);
+					} else {
+						$accessUrl = $this->getUrl($accessUrl, true/*リンク用*/);
+						//$this->gPage->redirect($accessUrl);
+						// ### キャッシュに残さない方法でリダイレクトする ###
+						$this->gPage->redirect($accessUrl, false, 303, false/*SSLは自動制御しない*/);
+						return;
+					}
 				}
 			} else {
 				// ダウンロード不可のときはエラーログを残す
@@ -476,6 +507,8 @@ class default_contentWidgetContainer extends default_contentBaseWidgetContainer
 	function itemsLoop($index, $fetchedRow)
 	{
 		$contentId = $fetchedRow['cn_id'];
+		$accessKey = $fetchedRow['cn_attach_access_key'];		// アクセスキー
+		$accessUrl = $fetchedRow['cn_attach_access_url'];		// アクセスキー取得用URL
 		
 		// ページタイトルの設定
 		if (empty($this->pageTitle)) $this->pageTitle = $fetchedRow['cn_name'];		// 画面タイトル、パンくずリスト用タイトル
@@ -535,8 +568,7 @@ class default_contentWidgetContainer extends default_contentBaseWidgetContainer
 			
 			$formName = '';
 			$funcName = '';
-			
-			$contentText = $fetchedRow['cn_html'];
+			$contentText = $fetchedRow['cn_html'];		// コンテンツ本文
 			
 			$accessPointUrl = '';		// コンテンツアクセスポイント
 			switch (default_contentCommonDef::$_deviceType){		// デバイスごとの処理
@@ -580,31 +612,65 @@ class default_contentWidgetContainer extends default_contentBaseWidgetContainer
 				$thumbUrl = $this->gInstance->getImageManager()->getSystemThumbUrl(M3_VIEW_TYPE_CONTENT, default_contentCommonDef::$_deviceType, $thumbFilenameArray[count($thumbFilenameArray) -1]);
 			}
 
+			// アクセスキーが設定されている場合アクセス制御を行う
+			$canDownloadAttachFile = false;			// 添付ファイルダウンロード不可
+			$sessionAccessKey = '';
+			if (empty($accessKey)){
+				$canDownloadAttachFile = true;		// 添付ファイルダウンロード可
+			} else {
+				// セッションのアクセスキーを確認
+				$sessionAccessKey = $this->gAccess->getSessionAccessKey($accessKey);
+				if (!empty($sessionAccessKey)) $canDownloadAttachFile = true;		// 添付ファイルダウンロード可
+			}
+			
 			// 添付ファイルダウンロード用リンク
 			$attachFileTag = '';
 			$attachContentSerial = $fetchedRow['cn_serial'];
 			if ($isDefaltContent) $attachContentSerial = $defaltContentRow['cn_serial'];
 			$ret = $this->gInstance->getFileManager()->getAttachFileInfo(default_contentCommonDef::$_viewContentType, $attachContentSerial, $attachFileRows);
 			if ($ret){
+				if (!$canDownloadAttachFile){			// ダウンロード不可のとき
+					// アクセスキー取得用URL
+					if (empty($accessUrl)){		// アクセスキー取得用URLが設定されていない場合
+						$this->writeError(__METHOD__, '添付ファイルのアクセスキー取得用のURLが設定されていません。コンテンツID=' . $contentId, 2200);
+					} else {
+						$accessUrl = $this->getUrl($accessUrl, true/*リンク用*/);
+					}
+				}
+				
 				$optionAttr = '';		// 追加属性
 				if ($this->jQueryMobileFormat) $optionAttr = 'rel="external"';			// jQueryMobile用のフォーマットで出力するかどうか
 				
-				$attachFileTag .= '<ul>';
-				for ($i = 0; $i < count($attachFileRows); $i++){
-					$fileTitle = $attachFileRows[$i]['af_title'];
-					if (empty($fileTitle)) $fileTitle = $attachFileRows[$i]['af_filename'];
+				if (empty($this->autoGenerateAttachFileList)){		// 添付ファイルリストを自動作成しない場合
+					// ##### コンテンツ本文を解析して添付ファイルダウンロード用のリンクを埋め込む #####
+					$this->attachFileRows = $attachFileRows;		// 添付ファイル情報(コンテンツ本文作成用)
+					$this->attachFileDownloadUrl = $canDownloadAttachFile ? '' : $accessUrl;			// 添付ファイルのリンク先URL(ダウンロード不可時のみ設定)
+					$pattern = '/' . preg_quote(M3_TAG_START . M3_TAG_MACRO_ITEM_KEY) . '(\d+)\|?(.*?)' . preg_quote(M3_TAG_END) . '/u';			// オプションパラメータは「|」以降(2015/4/20変更)
+					$contentText = preg_replace_callback($pattern, array($this, '_replace_content_macro_callback'), $contentText);
+				} else {		// 添付ファイルリストを自動生成する場合
+					$attachFileTag .= '<ul>';
+					for ($i = 0; $i < count($attachFileRows); $i++){
+						$fileTitle = $attachFileRows[$i]['af_title'];
+						if (empty($fileTitle)) $fileTitle = $attachFileRows[$i]['af_filename'];
 					
-					// ダウンロード用のリンク
-					$downloadUrl  = $this->gEnv->getDefaultUrl() . '?' . M3_REQUEST_PARAM_OPERATION_COMMAND . '=' . M3_REQUEST_CMD_DO_WIDGET;
-					$downloadUrl .= '&' . M3_REQUEST_PARAM_WIDGET_ID . '=' . $this->gEnv->getCurrentWidgetId();
-					$downloadUrl .= '&fileid=' . $attachFileRows[$i]['af_file_id'];
+						// ダウンロード用のリンク
+						// 添付ファイルがダウンロードできない状態のときはアクセスキー取得用のURLへリンク
+						if ($canDownloadAttachFile){			// ダウンロード可能のとき
+							$downloadUrl  = $this->gEnv->getDefaultUrl() . '?' . M3_REQUEST_PARAM_OPERATION_COMMAND . '=' . M3_REQUEST_CMD_DO_WIDGET;
+							$downloadUrl .= '&' . M3_REQUEST_PARAM_WIDGET_ID . '=' . $this->gEnv->getCurrentWidgetId();
+							$downloadUrl .= '&fileid=' . $attachFileRows[$i]['af_file_id'];
+							$downloadUrl = $this->getUrl($downloadUrl);
+						} else {
+							$downloadUrl = $accessUrl;
+						}
 						
-					$attachFileTag .= '<li>' . $this->convertToDispString($fileTitle);
-					$attachFileTag .= '<a href="' . $this->convertUrlToHtmlEntity($this->getUrl($downloadUrl)) . '" ' . $optionAttr . '>';
-					$attachFileTag .= '<img src="' . $this->getUrl($this->gEnv->getRootUrl() . self::DOWNLOAD_ICON_FILE) . '" width="' . self::DOWNLOAD_ICON_SIZE . '" height="' . self::DOWNLOAD_ICON_SIZE . '" title="ダウンロード" alt="ダウンロード" style="border:none;margin:0;padding:0;vertical-align:text-top;" />';
-					$attachFileTag .= '</a></li>';
+						$attachFileTag .= '<li>' . $this->convertToDispString($fileTitle);
+						$attachFileTag .= '<a href="' . $this->convertUrlToHtmlEntity($downloadUrl) . '" ' . $optionAttr . '>';
+						$attachFileTag .= '<img src="' . $this->getUrl($this->gEnv->getRootUrl() . self::DOWNLOAD_ICON_FILE) . '" width="' . self::DOWNLOAD_ICON_SIZE . '" height="' . self::DOWNLOAD_ICON_SIZE . '" title="ダウンロード" alt="ダウンロード" style="border:none;margin:0;padding:0;vertical-align:text-top;" />';
+						$attachFileTag .= '</a></li>';
+					}
+					$attachFileTag .= '</ul>';
 				}
-				$attachFileTag .= '</ul>';
 			}
 			
 			// 関連コンテンツリンク
@@ -798,5 +864,58 @@ class default_contentWidgetContainer extends default_contentBaseWidgetContainer
 		}
 		return $contentText;
 	}
+	/**
+	 * 添付ファイルリンク変換コールバック関数
+	 *
+	 * @param array $matchData		検索マッチデータ
+	 * @return string				変換後データ
+	 */
+    function _replace_content_macro_callback($matchData)
+	{
+		$destTag	= $matchData[0];
+		$itemNo		= $matchData[1];	// 添付ファイルの項目No
+		$options	= $matchData[2];	// オプション文字列
+
+		// オプションを解析
+		$option = '';
+		if (!empty($options)){
+			list($option, $optionValue) = array_map('trim', explode('=', $options));
+			$option = strtolower($option);
+		}
+
+		// デフォルトのファイルタイトルを取得
+		$index = $itemNo -1;
+		$fileTitle = $this->attachFileRows[$index]['af_title'];
+		if (empty($fileTitle)) $fileTitle = $this->attachFileRows[$index]['af_filename'];
+		if (empty($fileTitle)) $fileTitle = $this->attachFileRows[$index]['af_original_filename'];
+		
+		switch ($option){
+		case 'title':
+			if (!empty($optionValue)) $fileTitle = $optionValue;
+			break;
+		case 'tag':
+		default:
+			break;
+		}
+		
+		// ダウンロード用のリンク
+		if (empty($this->attachFileDownloadUrl)){
+			$downloadUrl  = $this->gEnv->getDefaultUrl() . '?' . M3_REQUEST_PARAM_OPERATION_COMMAND . '=' . M3_REQUEST_CMD_DO_WIDGET;
+			$downloadUrl .= '&' . M3_REQUEST_PARAM_WIDGET_ID . '=' . $this->gEnv->getCurrentWidgetId();
+			$downloadUrl .= '&fileid=' . $this->attachFileRows[$index]['af_file_id'];
+			$downloadUrl = $this->getUrl($downloadUrl);
+		} else {
+			$downloadUrl = $this->attachFileDownloadUrl;
+		}
+		$destTag = '<a href="' . $this->convertUrlToHtmlEntity($downloadUrl) . '">';
+		if ($option == 'tag'){
+			$destTag .= $optionValue;
+		} else {
+			$destTag .= $this->convertToDispString($fileTitle);
+		}
+		$destTag .= '</a>';
+
+		return $destTag;
+	}
 }
 ?>
