@@ -8,7 +8,7 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2015 Magic3 Project.
+ * @copyright  Copyright 2006-2017 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
  * @version    SVN: $Id$
  * @link       http://www.magic3.org
@@ -204,9 +204,6 @@ foreach (array(WikiConfig::getDefaultPage()) as $page){
 	// 初期化前にDBの内容を必ず確認する
 	if (!WikiPage::isExistsPage($page)) WikiPage::initPage($page, '', true/*ページ一覧更新*/);		// ページ初期化
 }
-	
-// 入力チェック
-if (!WikiParam::checkParam()) die('Using both cmd= and plugin= is not allowed');
 
 /////////////////////////////////////////////////
 // 初期設定($WikiName,$BracketNameなど)
